/*-- Copyright (c) 2011 by SAS Institute Inc., Cary, NC, USA. All Rights Reserved. --*/
/*
Model         	DDCF FM Integration  
Subject Area  	Financial Management Integration
Version
Name          	DDCF 5.3: Macro to Publish Formset
DBMS          	SAS
Created by 		Abhijeet Murumkar, Ganesh Gurunathan
Created on 		17/06/2011 14:45:00 PM
Last updated 	21/09/2011 16:00:00 PM

* Copyright (c) 2011 by SAS Institute Inc., Cary, NC 27513

Input Parameters 
1. plan_id		Plan identification number

*/

data _null_;
	call symputx('VarDtStr',TRANWRD(('_'|| put(date(),YYMMDDN.) || '_' || put(time(),HHMM.) || '.log'),':','_'));
run;

%let logfilenm=publish_%sysfunc(ktrim(&plan_id.))&VarDtStr.;
%let logfilepath=&GL_DDF_CONFIG_DIR_PATH./logs/;

proc printto log="&logfilepath.&logfilenm."; 
run;

%macro ddcf_fm_publish_formset_stp;

%if &GL_FRAMEWORK_DB_IND.=&GL_SHORT_NO. %then %do;
	libname uiart MYSQL  INSERTBUFF=&GL_MYSQL_INSERTBUFF. DBINDEX=YES bulkload = yes  MYSQL_PORT=3306 DBCONINIT = &GL_MYSQL_DBCONINIT.
	DATABASE=&GL_TRANS_DATABASE_NM. SERVER="&GL_TRANS_DB_SERVER."  authdomain = &GL_MYSQL_AUTH_DOMAIN. ; 
%end;

libname sassdm MYSQL  INSERTBUFF=&GL_MYSQL_INSERTBUFF. DBINDEX=YES bulkload = yes  MYSQL_PORT=3306 DBCONINIT = &GL_MYSQL_DBCONINIT.
DATABASE=&GL_FM_MYSQL_DATABASE_NM. SERVER="&GL_FM_MYSQL_SERVER."  authdomain = &GL_FM_MYSQL_AUTH_DOMAIN. ;


/* Define connection string for transactional server*/
%ddcf_connect_to_trans_db;

	%let job_rc=0;
	%let job_rc_msg=;

	/* Get schema id */

	%let schema_id=;
	%ddcf_get_schema_id(plan_id=&plan_id.);
	%let schema_id=%sysfunc(ktrim(%sysfunc(kleft(&schema_id.))));
	%put &schema_id.;

	%if (&job_rc<5) %then %do;

		%let cycle_id=0;

		proc sql noprint;
			select cycle_id into :cycle_id
			from sassdm.sas_cycle_data
			where ktrim(kleft(kupcase(CYCLE_NM))) = %sysfunc(kupcase("&schema_id."));
		quit;
		%RCSet(&sqlrc);

		%if (&job_rc>4) %then %do;
			%goto exit;
		%end;

		%if &cycle_id. > 0 %then %do;

			proc sql noprint;
				select FORM_SET_NM into :FORM_SET_NMS separated by ','
				from sassdm.sas_form_set
				where CYCLE_ID = &cycle_id.;
			quit;
			%RCSet(&sqlrc);

			%if (&job_rc>4) %then %do;
				%goto exit;
			%end;

			%let k=1;

			%let blist=%sysfunc(kscan(%quote(%sysfunc(strip(&FORM_SET_NMS.))),&k., %str(,)));
					
			%do %while (%quote(&blist.) ne);

					%let formset=;
					%let formset=%nrquote(%sysfunc(kleft(%sysfunc(ktrim(&blist.)))));
					%let k=%eval(&k.+1);

					data _null_ /picklist='finance/finance.txt' saveclassl='finbatch' getclassl='finbatch';
				   		declare javaobj formset;
				 		formset=_new_ javaobj("com/sas/solutions/finance/api/FormSet");
						formset.ExceptionDescribe(1);

						call METADATA_PASSID("formset", "");
						formset.callVoidMethod('setCycle','FM',"&schema_id.");
						formset.callVoidMethod('setFormSet',"&formset.");
						formset.callVoidMethod('enableUserNotification');
				 		formset.callVoidMethod('enableCommentRetirement');
				 		formset.callVoidMethod('setComment','My reset comment');
				 		formset.callVoidMethod('publish');
						formset.delete();

					 run;
					 %RCSet(&syserr);

					 %if (&job_rc>4) %then %do;
						%goto exit;
					%end;

					%let blist=%sysfunc(kscan(%quote(%sysfunc(strip(&FORM_SET_NMS.))),&k., %str(,)));
			%end; 

		%end;
	%end;

	%if (&job_rc<5) %then %do;
	/* Form Published */
		%let consensus_status=16;
	%end;
	%else %do;
	/* Form Publish Fail */
		%let consensus_status=15;
	%end;
	proc sql;
		update uiart.plan_consensus_details 
		set STATUS_CD = &consensus_status. 
		where plan_id = &plan_id.;
	quit;
	%RCSet(&sqlrc);

	libname sassdm clear;

 %exit: 

%if &GL_FRAMEWORK_DB_IND.=&GL_SHORT_NO. %then %do;
	libname uiart clear;
%end;

%mend;

%ddcf_fm_publish_formset_stp;
proc printto; 
run;
